/**
 * @file
 * Contains user_online_status.js.
 */

(function (Drupal, drupalSettings) {
  'use strict';
  Drupal.behaviors.UserOnlineStatus = {
    attach: function (context) {

      // Collect all uid's on page.
      var statusWrapperArray = Array.prototype.slice.call(context.querySelectorAll('.user-online-status'));
      var uids = [];
      statusWrapperArray.forEach(function (el) {
        uids.push(el.getAttribute('data-user-online-status-uid'));
      });

      var printOnlineStatus = function (uid, status) {
        var statusWrapperElement = {};
        // Get status wrapper element of current user.
        statusWrapperArray.some(function (el, i) {
          if (el.getAttribute('data-user-online-status-uid') === uid) {
            statusWrapperElement = el;
            // Remove wrapper from list as it is no longer needed.
            statusWrapperArray.splice(i, 1);
            return true;
          }
        });

        var responseElement = statusWrapperElement.querySelector('.response');
        setStatusClasses(statusWrapperElement, status);

        // Print status.
        switch (status) {
          case 'online':
            responseElement.innerHTML = Drupal.t('online');
            break;

          case 'absent':
            responseElement.innerHTML = Drupal.t('absent');
            break;

          case 'offline':
            responseElement.innerHTML = Drupal.t('offline');
            break;

          default:
            console.log('user_online_status: Status not found.');
        }
      };

      // Fetch status.
      if (uids.length) {
        var request = new XMLHttpRequest();
        request.open('GET', '/online-status/' + uids.join(','), true);

        request.onload = function () {
          if (request.status >= 200 && request.status < 400) {
            var response = JSON.parse(request.responseText);
            for (var uid in response) {
              printOnlineStatus(uid, response[uid]);
            }
          }
          else {
            console.log('user_online_status: Error fetching status.');
          }
        };
        request.onerror = function () {
          // There was a connection error of some sort.
          console.log('user_online_status: Could not fetch status.');
        };

        request.send();
      }
    }
  };

  function setStatusClasses(el, currentStatus) {
    var statusClasses = drupalSettings.user_online_status.classes;
    var statusElement = el.querySelector('.status');

    for (var statusClass in statusClasses) {
      if (statusElement.classList.contains(status)) {
        statusElement.classList.remove(statusClass, ...(statusClasses[statusClass].split(' ')));
      }
    }
    statusElement.classList.add(currentStatus);
    if (statusClasses[currentStatus]) {
      statusElement.classList.add(...(statusClasses[currentStatus].split(' ')));
    }
  }
})(Drupal, drupalSettings);
